.. nodoctest

Lyapunov exponents (comparison)
===============================

.. This file has been autogenerated.

.. automodule:: slabbe.lyapunov
   :members:
   :undoc-members:
   :show-inheritance:
   

